@@ -4,19 +4,18 @@
  *  
  *  Copyright (C) 2011 Peng Wu <alexepico@gmail.com>
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -41,7 +40,7 @@ typedef struct _import_iterator_t import_iterator_t;
 typedef struct _export_iterator_t export_iterator_t;
 
 typedef enum _lookup_candidate_type_t{
-    BEST_MATCH_CANDIDATE = 1,
+    NBEST_MATCH_CANDIDATE = 1,
     NORMAL_CANDIDATE,
     ZOMBIE_CANDIDATE,
     PREDICTED_CANDIDATE,
@@ -352,6 +351,7 @@ bool pinyin_phrase_segment(pinyin_instance_t * instance,
 /**
  * pinyin_get_sentence:
  * @instance: the pinyin instance.
+ * @index: the index of the nbest result.
  * @sentence: the saved sentence in the instance.
  * @returns: whether the sentence is already saved in the instance.
  *
@@ -361,6 +361,7 @@ bool pinyin_phrase_segment(pinyin_instance_t * instance,
  *
  */
 bool pinyin_get_sentence(pinyin_instance_t * instance,
+                         guint8 index,
                          char ** sentence);
 
 /**
@@ -545,12 +546,13 @@ bool pinyin_lookup_tokens(pinyin_instance_t * instance,
 /**
  * pinyin_train:
  * @instance: the pinyin instance.
+ * @index: the index of the nbest result.
  * @returns: whether the sentence is trained.
  *
  * Train the current user input sentence.
  *
  */
-bool pinyin_train(pinyin_instance_t * instance);
+bool pinyin_train(pinyin_instance_t * instance, guint8 index);
 
 /**
  * pinyin_reset:
@@ -787,6 +789,20 @@ bool pinyin_get_candidate_string(pinyin_instance_t * instance,
                                  lookup_candidate_t * candidate,
                                  const gchar ** utf8_str);
 
+/**
+ * pinyin_get_candidate_nbest_index:
+ * @instance: the pinyin instance.
+ * @candidate: the lookup candidate.
+ * @index: the index of the nbest result.
+ * @returns: whether the get operation is successful.
+ *
+ * Get the nbest index of the candidate.
+ *
+ */
+bool pinyin_get_candidate_nbest_index(pinyin_instance_t * instance,
+                                      lookup_candidate_t * candidate,
+                                      guint8 * index);
+
 /**
  * pinyin_get_pinyin_key:
  * @instance: the pinyin instance.
@@ -889,6 +905,7 @@ bool pinyin_get_right_pinyin_offset(pinyin_instance_t * instance,
 /**
  * pinyin_get_character_offset:
  * @instance: the pinyin instance.
+ * @phrase: the utf8 phrase.
  * @offset: the lookup offset.
  * @length: the character offset.
  * @returns: whether the get operation is successful.
@@ -897,6 +914,7 @@ bool pinyin_get_right_pinyin_offset(pinyin_instance_t * instance,
  *
  */
 bool pinyin_get_character_offset(pinyin_instance_t * instance,
+                                 const char * phrase,
                                  size_t offset,
                                  size_t * length);
 
